package com.gct.tool.config;

import com.gct.tool.quartztask.LoadBaseDataTask;
import com.gct.tool.quartztask.ProduceTask;
import org.quartz.JobBuilder;
import org.quartz.JobDetail;
import org.quartz.Trigger;
import org.quartz.TriggerBuilder;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import static org.quartz.CronScheduleBuilder.cronSchedule;

/**
 * class name: QuartzTaskConfig
 *
 * @author lloyd
 * @version 1.0
 * @since 2021/5/21 上午10:21
 */
@Configuration
public class QuartzTaskConfig {

    @Bean
    public JobDetail jobDetail1() {
        try {
            return JobBuilder.newJob(LoadBaseDataTask.class)
                    .withIdentity("LoadBaseData" ,"Group1")
                    .storeDurably()
                    .build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create JobDetail bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),"LoadBaseData","Group1");
            throw e;
        }
    }

    @Bean
    public Trigger trigger1() {
        try {
            return TriggerBuilder.newTrigger()
                    .forJob("LoadBaseData", "Group1")
                    .withSchedule(cronSchedule("0/1 0 0/1 * * ?")).build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create Trigger bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),"LoadBaseData","Group1");
            throw e;
        }
    }

    @Bean
    public JobDetail jobDetail2() {
        try {
            return JobBuilder.newJob(ProduceTask.class)
                    .withIdentity("Produce" ,"Group1")
                    .storeDurably()
                    .build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create JobDetail bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),"LoadBaseData","Group1");
            throw e;
        }
    }

    @Bean
    public Trigger trigger2() {
        try {
            return TriggerBuilder.newTrigger()
                    .forJob("Produce", "Group1")
                    .withSchedule(cronSchedule("0/1 0 0/1 * * ?")).build();
        } catch (Exception e) {
            LoggerFactory.getLogger(this.getClass()).error("Create Trigger bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),"Produce","Group1");
            throw e;
        }
    }
}
