package com.gct.tool.entity.sql;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.*;
import java.util.stream.Collectors;

@Data
@AllArgsConstructor
public class QueryBody {

    public Map<String, Object> body;
    private List<String> dataRegions;
    private Filter filter;

    public Map<String,Object> toJsonMap(){
        return JSONObject.parseObject(JSON.toJSONString(this));
    }

    public QueryBody() {
        dataRegions = new ArrayList<>();
        filter = new Filter();

    }

    public QueryBody select(String... column) {
        dataRegions.addAll(Arrays.stream(column).collect(Collectors.toList()));
        return this;
    }

    private QueryBody parse(String column, String value, String symbol) {
        SubFilter subFilter = new SubFilter();
        subFilter.key = column;
        subFilter.singleValue = value;
        subFilter.logic = "AND";
        subFilter.symbol = symbol;
        filter.subFilter.add(subFilter);
        return this;
    }

    public QueryBody eq(String column, String value) {
        return parse(column, value, "=");
    }

    public QueryBody gt(String column, String value) {
        return parse(column, value, ">");
    }

    public QueryBody ge(String column, String value) {
        return parse(column, value, ">=");
    }

    public QueryBody lt(String column, String value) {
        return parse(column, value, "<");
    }

    public QueryBody le(String column, String value) {
        return parse(column, value, "<=");
    }
}

@Data
@AllArgsConstructor
class Filter {
    public Filter() {
        key = "";
        logic = "AND";
        subFilter = new ArrayList<>();
    }

    String key;
    String logic;
    List<SubFilter> subFilter;

}

@Data
@AllArgsConstructor
@NoArgsConstructor
class SubFilter {
    String key;
    String logic;
    String symbol;
    String singleValue;
}